/*
 *   Copyright 2012 Brian Rosenberger (Brutex Network)
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */

package net.brutex.xservices.types;

import net.brutex.xservices.util.BrutexNamespaces;


/**
 * Host information.
 * @author Brian Rosenberger, bru@brutex.de
 */
@javax.xml.bind.annotation.XmlType(name=HostinfoType.XML_NAME, namespace=BrutexNamespaces.WS_XSERVICES)
public class HostinfoType {

	public final static String XML_NAME="hostinfo";
    private String name;
    private String domain;
    private String ip4;
    private String ip6;
        
	/**
	 * Create a new HostinfoType. 
	 */
	public HostinfoType() {
    }
	
	/**
	 * Create a new HostinfoType.
	 * 
	 * @param name
	 * @param domain
	 * @param ip4
	 * @param ip6
	 */
	public HostinfoType(String name, String domain, String ip4, String ip6) {
		this.name = name;
		this.domain = domain;
		this.ip4 = ip4;
		this.ip6 = ip6;
	}

	/**
	 * Get the host name.
	 * 
	 * @return the name
	 */
	public String getName() {
		return name;
	}
	/**
	 *  Set the host name.
	 *  
	 * @param name the name to set
	 */
	public void setName(String name) {
		this.name = name;
	}
	/**
	 * Get the host domain.
	 * 
	 * @return the domain
	 */
	public String getDomain() {
		return domain;
	}
	/**
	 * Set the host domain.
	 * 
	 * @param domain the domain to set
	 */
	public void setDomain(String domain) {
		this.domain = domain;
	}
	/**
	 * Get the IP address version 4 representation for this host.
	 * @return the ip4
	 */
	public String getIp4() {
		return ip4;
	}
	/**
	 * Set the IP address version 4.
	 * @param ip4 the ip4 to set
	 */
	public void setIp4(String ip4) {
		this.ip4 = ip4;
	}
	/**
	 * Get the IP address version 6 representation for this host.
	 * @return the ip6
	 */
	public String getIp6() {
		return ip6;
	}
	/**
	 * Set the IP address version 6 representation for this host.
	 * @param ip6 the ip6 to set
	 */
	public void setIp6(String ip6) {
		this.ip6 = ip6;
	}
}
