/*
 *   Copyright 2010 Brian Rosenberger (Brutex Network)
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */

package net.brutex.xservices.types.ant;

import java.util.UUID;

import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;

/**
 * Defines a collection of storable objects.
 * 
 * @author Brian Rosenberger
 * @since 1.0
 */
@XmlType()
public class CollectionType {

	private String name="";
	final private UUID uuid;

	/**
	 * @return the name
	 */
	public String getName() {
		return name;
	}

	/**
	 * @param name the name to set
	 */
	@XmlElement(required=true)
	public void setName(String name) {
		this.name = name;
	}
	
	/**
	 * @return
	 */
	public String getUuid() {
		return uuid.toString();
	}

	/**
	 * @param name
	 * @param uuid
	 */
	public CollectionType(String name, UUID uuid) {
		this.name = name;
		this.uuid = uuid;
	}
	
	/**
	 * @param name
	 * @param uuid
	 */
	public CollectionType(String name) {
		this.name = name;
		this.uuid = UUID.randomUUID();
	}
	
	
	/**
	 */
	public CollectionType() {
		this.name = "";
		this.uuid = UUID.randomUUID();
	}	

}
